@@ -91,6 +91,29 @@ def clear():
     pb = NSPasteboard.generalPasteboard()
     pb.clearContents()
 
+class Pasteboard(object):
+    """
+    A different way of packaging the copy/paste/clear functionality.
+    Came after the functional interface, so really is just a veneer on it.
+    """
+    
+    def available(self, *args, **kwargs):
+        return available(*args, **kwargs)
+    
+    def get_contents(self, *args, **kwargs):
+        return paste(*args, **kwargs)
+    
+    def get_all_contents(self, *args, **kwargs):
+        return pasteall(*args, **kwargs)
+    
+    def set_contents(self, *args, **kwargs):
+        return copy(*args, **kwargs)
+        
+    def clear(self, *args, **kwargs):
+        return clear(*args, **kwargs)
+
+
+pasteboard = Pasteboard()
 
 def dict_print(d, heading=None, wrap=True, **kwargs):
     """
@@ -109,20 +132,3 @@ def dict_print(d, heading=None, wrap=True, **kwargs):
             print '\n'.join(textwrap.wrap(item_text, **kwargs))
         else:
             print item_text
-    
-def test_richxerox():
-    """
-    Let's try it out!
-    """
-    print available()
-    print paste()
-    dict_print(pasteall(), 'ALL CONTENTS')
-    
-    clear()
-    dict_print(pasteall(), 'AFTER CLEAR')
-    
-    copy(text="this is good!", html="this is <strong>good</strong>!")
-    dict_print(pasteall(), 'AFTER COPY')
-    
-if __name__ == '__main__':
-    test_richxerox()
\ No newline at end of file
